==> apdu_service_plugin-0.0.10.tar.gz: lib/apdu_service_plugin.dart <==
import 'dart:async';
import 'dart:ffi';

import 'package:flutter/services.dart';

class ApduServicePlugin {
  static const MethodChannel _channel = MethodChannel('apdu_service_plugin');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<bool> startApdu(String nfcCode, String broadastPackageName,
      String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('startApdu', {
      'NFC_CODE': nfcCode,
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }

  static Future<bool> stopApdu(
      String broadastPackageName, String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('stopApdu', {
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }

  static Future<bool> startApduBroadcast(String nfcCode, String broadastPackageName,
      String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('startApduBroadcast', {
      'NFC_CODE': nfcCode,
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }

  static Future<bool> stopApduBroadcast(
      String broadastPackageName, String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('stopApduBroadcast', {
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }
}

==> apdu_service_plugin-0.0.11.tar.gz: lib/apdu_service_plugin.dart <==
import 'dart:async';
import 'dart:ffi';

import 'package:flutter/services.dart';

class ApduServicePlugin {
  static const MethodChannel _channel = MethodChannel('apdu_service_plugin');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<bool> startApdu(String nfcCode, String broadastPackageName,
      String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('startApdu', {
      'NFC_CODE': nfcCode,
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }

  static Future<bool> stopApdu(
      String broadastPackageName, String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('stopApdu', {
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }

  static Future<bool> startApduBroadcast(String nfcCode,
      String broadastPackageName, String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('startApduBroadcast', {
      'NFC_CODE': nfcCode,
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }

  static Future<bool> stopApduBroadcast(
      String broadastPackageName, String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('stopApduBroadcast', {
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }

  static Future<bool> setSharedPreferences(
      String broadastPackageName, String broadcastComponentName) async {
    final bool result = await _channel.invokeMethod('setSharedPreferences', {
      'SERVICE_PACKAGE_NAME': broadastPackageName,
      'SERVICE_COMPONENT_NAME': broadcastComponentName,
    });
    return result;
  }
}
